about summary refs log tree commit diff
path: root/stdlib/tst-strtol-binary-gnu11.c
diff options
context:
space:
mode:
authorJoseph Myers <josmyers@redhat.com>2024-02-01 11:02:01 +0000
committerJoseph Myers <josmyers@redhat.com>2024-02-01 11:02:01 +0000
commit42cc619dfbc44e263239c2de870bae11ad65810a (patch)
tree13f7e2f0ad1e9b3c4a36f9ecd4e3e49b1d268120 /stdlib/tst-strtol-binary-gnu11.c
parent7c8df0b9441e34928f2d7d70531e3d55e016c32e (diff)
downloadglibc-42cc619dfbc44e263239c2de870bae11ad65810a.tar.gz
glibc-42cc619dfbc44e263239c2de870bae11ad65810a.tar.xz
glibc-42cc619dfbc44e263239c2de870bae11ad65810a.zip
Refer to C23 in place of C2X in glibc
WG14 decided to use the name C23 as the informal name of the next
revision of the C standard (notwithstanding the publication date in
2024).  Update references to C2X in glibc to use the C23 name.

This is intended to update everything *except* where it involves
renaming files (the changes involving renaming tests are intended to
be done separately).  In the case of the _ISOC2X_SOURCE feature test
macro - the only user-visible interface involved - support for that
macro is kept for backwards compatibility, while adding
_ISOC23_SOURCE.

Tested for x86_64.
Diffstat (limited to 'stdlib/tst-strtol-binary-gnu11.c')
-rw-r--r--stdlib/tst-strtol-binary-gnu11.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/stdlib/tst-strtol-binary-gnu11.c b/stdlib/tst-strtol-binary-gnu11.c
index 4e1d39bc21..98b63c0ae1 100644
--- a/stdlib/tst-strtol-binary-gnu11.c
+++ b/stdlib/tst-strtol-binary-gnu11.c
@@ -1,5 +1,5 @@
-/* Test strtol functions with C2X binary integers (narrow strings, GNU
-   extensions, C2X strtol features disabled).
+/* Test strtol functions with C23 binary integers (narrow strings, GNU
+   extensions, C23 strtol features disabled).
    Copyright (C) 2022-2024 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -20,15 +20,15 @@
 #include <features.h>
 /* This file tests the old versions of GNU extension functions, which
    are not normally available to new binaries because GNU extensions
-   normally imply C2X strtol features.  */
-#undef __GLIBC_USE_C2X_STRTOL
-#define __GLIBC_USE_C2X_STRTOL 0
+   normally imply C23 strtol features.  */
+#undef __GLIBC_USE_C23_STRTOL
+#define __GLIBC_USE_C23_STRTOL 0
 
 #define CHAR char
 #define WIDE 0
 #define FNPFX strto
 #define L_(C) C
-#define TEST_C2X 0
+#define TEST_C23 0
 #define TEST_Q 1
 #define TEST_LOCALE 1